@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,10 @@ from typing import Dict, Type
 from .base import GameServerClustersServiceTransport
 from .grpc import GameServerClustersServiceGrpcTransport
 from .grpc_asyncio import GameServerClustersServiceGrpcAsyncIOTransport
-
+from .rest import (
+    GameServerClustersServiceRestInterceptor,
+    GameServerClustersServiceRestTransport,
+)
 
 # Compile a registry of transports.
 _transport_registry = (
@@ -27,9 +30,12 @@ _transport_registry = (
 )  # type: Dict[str, Type[GameServerClustersServiceTransport]]
 _transport_registry["grpc"] = GameServerClustersServiceGrpcTransport
 _transport_registry["grpc_asyncio"] = GameServerClustersServiceGrpcAsyncIOTransport
+_transport_registry["rest"] = GameServerClustersServiceRestTransport
 
 __all__ = (
     "GameServerClustersServiceTransport",
     "GameServerClustersServiceGrpcTransport",
     "GameServerClustersServiceGrpcAsyncIOTransport",
+    "GameServerClustersServiceRestTransport",
+    "GameServerClustersServiceRestInterceptor",
 )
