@@ -19,6 +19,10 @@ from typing import Dict, Type
 from .base import GameServerDeploymentsServiceTransport
 from .grpc import GameServerDeploymentsServiceGrpcTransport
 from .grpc_asyncio import GameServerDeploymentsServiceGrpcAsyncIOTransport
+from .rest import (
+    GameServerDeploymentsServiceRestInterceptor,
+    GameServerDeploymentsServiceRestTransport,
+)
 
 # Compile a registry of transports.
 _transport_registry = (
@@ -26,9 +30,12 @@ _transport_registry = (
 )  # type: Dict[str, Type[GameServerDeploymentsServiceTransport]]
 _transport_registry["grpc"] = GameServerDeploymentsServiceGrpcTransport
 _transport_registry["grpc_asyncio"] = GameServerDeploymentsServiceGrpcAsyncIOTransport
+_transport_registry["rest"] = GameServerDeploymentsServiceRestTransport
 
 __all__ = (
     "GameServerDeploymentsServiceTransport",
     "GameServerDeploymentsServiceGrpcTransport",
     "GameServerDeploymentsServiceGrpcAsyncIOTransport",
+    "GameServerDeploymentsServiceRestTransport",
+    "GameServerDeploymentsServiceRestInterceptor",
 )
