@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,15 +19,18 @@ from typing import Dict, Type
 from .base import RealmsServiceTransport
 from .grpc import RealmsServiceGrpcTransport
 from .grpc_asyncio import RealmsServiceGrpcAsyncIOTransport
-
+from .rest import RealmsServiceRestInterceptor, RealmsServiceRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[RealmsServiceTransport]]
 _transport_registry["grpc"] = RealmsServiceGrpcTransport
 _transport_registry["grpc_asyncio"] = RealmsServiceGrpcAsyncIOTransport
+_transport_registry["rest"] = RealmsServiceRestTransport
 
 __all__ = (
     "RealmsServiceTransport",
     "RealmsServiceGrpcTransport",
     "RealmsServiceGrpcAsyncIOTransport",
+    "RealmsServiceRestTransport",
+    "RealmsServiceRestInterceptor",
 )
