@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import duration_pb2  # type: ignore
@@ -131,7 +133,18 @@ class OperationStatus(proto.Message):
     """
 
     class ErrorCode(proto.Enum):
-        r""""""
+        r"""
+
+        Values:
+            ERROR_CODE_UNSPECIFIED (0):
+                No description available.
+            INTERNAL_ERROR (1):
+                No description available.
+            PERMISSION_DENIED (2):
+                No description available.
+            CLUSTER_CONNECTION (3):
+                No description available.
+        """
         ERROR_CODE_UNSPECIFIED = 0
         INTERNAL_ERROR = 1
         PERMISSION_DENIED = 2
