@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,9 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import proto  # type: ignore
 
-
-__protobuf__ = proto.module(package="google.cloud.gaming.v1beta", manifest={},)
+__protobuf__ = proto.module(
+    package="google.cloud.gaming.v1beta",
+    manifest={},
+)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
